How to generate a PIP package?
https://packaging.python.org/en/latest/tutorials/packaging-projects/

change setup.cfg version
py -m build
py -m twine upload --skip-existing dist/*

api-key=pypi-AgEIcHlwaS5vcmcCJDY5Mjc4MWVmLTNhMjQtNDY2ZS05ZmU1LTAyZGIxMDMxNjk2NwACFlsxLFsic2NyYXBlYW55dGhpbmciXV0AAixbMixbIjU3MTA5MDEwLTdmYTEtNGMzNi1hZGVhLTg1NGZiYmI0OWYwMyJdXQAABiAGd1VWaKHDFt8m-OKPoQU7HnFfNOVmqmBxZHNp0gAoZg